@@ -2,7 +2,8 @@
 (function(){var a=Ext.Component.prototype.initComponent,b=Ext.Component.prototype.destroy;Ext.override(Ext.Component,{stateful:false,statefulRelativeDimensions:true,statefulName:undefined,initComponent:function(){if(this.stateful!==false){if(!this.stateId)this.stateId=Ext.id(null,"state-");Ext.state.Manager.register(this)}a.apply(this,arguments)},getStateName:function(){var c=this.statefulName;c||(c=this.getXType().match(/(?:zarafa\.)?(.*)/)[1]);return c},destroy:function(){if(this.plugins)for(var c in this.plugins){var d=
 this.plugins[c];d instanceof Ext.util.Observable&&d.purgeListeners()}this.stateful!==false&&Ext.state.Manager.unregister(this);b.apply(this,arguments)}})})();(function(){Ext.override(Ext.Container,{bufferResize:false})})();
 (function(){Ext.Element.addMethods({addUnits:function(a){if(Ext.isEmpty(a)||a=="auto")a=a||"";else if(isNaN(a))a="";else/\d+(px|em|%|en|ex|pt|in|cm|mm|pc)$/i.test(a)||(a+=this.defaultUnit||"px");return a},swallowEvent:function(a,b){var c=this,d=b===true?this.swallowEventHandlerPreventDefault:this.swallowEventHandler;if(Ext.isArray(a)){Ext.each(a,function(j){c.on(j,d,this)});return c}c.on(a,d,this);return c},swallowEventHandler:function(a){a.stopPropagation()},swallowEventHandlerPreventDefault:function(a){a.stopPropagation();
-a.preventDefault()},spitOutEvent:function(a,b){var c=this,d=b===true?this.swallowEventHandlerPreventDefault:this.swallowEventHandler;if(Ext.isArray(a)){Ext.each(a,function(j){c.un(j,d,this)});return c}c.un(a,d,this);return c},selectable:function(){this.dom.unselectable="off";return this.spitOutEvent("selectstart",true).removeClass("x-unselectable")},clearClass:function(){this.dom.className=""}})})();
+a.preventDefault()},spitOutEvent:function(a,b){var c=this,d=b===true?this.swallowEventHandlerPreventDefault:this.swallowEventHandler;if(Ext.isArray(a)){Ext.each(a,function(j){c.un(j,d,this)});return c}c.un(a,d,this);return c},selectable:function(){this.dom.unselectable="off";return this.spitOutEvent("selectstart",true).removeClass("x-unselectable")},clearClass:function(){this.dom.className=""},fireEvent:function(a){var b=/^(scroll|resize|load|unload|abort|error)$/,c=/^(focus|blur|select|change|reset|keypress|keydown|keyup)$/;
+a=a.toLowerCase();a.replace(/^on/,"");var d;if(/^(click|dblclick|mousedown|mouseup|mouseover|mouseout|contextmenu)$/.test(a)){d=this.getBox();b=d.x+d.width/2;c=d.y+d.height/2;d=document.createEvent("MouseEvents");d.initMouseEvent(a,true,true,window,a=="dblclick"?2:1,b,c,b,c,false,false,false,false,0,null)}else if(c.test(a)){d=document.createEvent("UIEvents");d.initUIEvent(a,true,true,window,0)}else if(b.test(a)){d=document.createEvent("HTMLEvents");d.initEvent(a,true,true)}d&&this.dom.dispatchEvent(d)}})})();
 (function(){Ext.apply(Ext.EventManager,function(){function a(f){var i=false,g=0,k=A.length,n=false,l;if(f){if(f.getElementById||f.navigator){for(;g<k;++g){l=A[g];try{if(l.el===f){i=l.id;break}}catch(m){}}if(!i){i=Ext.id(f);A.push({id:i,el:f});n=true}}else i=Ext.id(f);if(!Ext.elCache[i]){Ext.Element.addToCache(new Ext.Element(f),i);if(n)Ext.elCache[i].skipGC=true}}return i}function b(f,i,g,k,n,l){f=Ext.getDom(f);var m=a(f);m=Ext.elCache[m].events;var p;p=v.on(f,i,n);m[i]=m[i]||[];m[i].push([g,n,l,
 p,k]);if(f.addEventListener&&i=="mousewheel"){var r=["DOMMouseScroll",n,false];f.addEventListener.apply(f,r);Ext.EventManager.addListener(B,"unload",function(){f.removeEventListener.apply(f,r)})}f==t&&i=="mousedown"&&Ext.EventManager.stoppedMouseDownEvent.addListener(n)}function c(){if(window!=top)return false;try{t.documentElement.doScroll("left")}catch(f){return false}h();return true}function d(){if(Ext.isIE&&c())return true;if(t.readyState==F){h();return true}x||(y=setTimeout(arguments.callee,
 2));return false}function j(){C||(C=Ext.query("style, link[rel=stylesheet]"));if(C.length==t.styleSheets.length){h();return true}x||(y=setTimeout(arguments.callee,2));return false}function e(){t.removeEventListener(z,arguments.callee,false);j()}function h(){if(!x){x=true;y&&clearTimeout(y);G&&t.removeEventListener(z,h,false);Ext.isIE&&d.bindIE&&t.detachEvent("onreadystatechange",d);v.un(B,"load",arguments.callee)}if(u&&!Ext.isReady){Ext.isReady=true;u.fire();u.listeners=[]}}function o(f,i){return function(){var g=
@@ -32,7 +33,8 @@ this.fireEvent("activate",this)},fixKeys:function(){if(Ext.isIE)return function(
 d.ENTER){j=this.win.getSelection();if(j.getRangeAt&&j.rangeCount){h=j.getRangeAt(0);h.deleteContents();o=h.commonAncestorContainer;if(!o||o.nodeName.toLowerCase()!="li"&&o.parentNode.nodeName.toLowerCase()!="li"){d.stopEvent();d=e.createElement("div");d.innerHTML="<br />";for(e=e.createDocumentFragment();o=d.firstChild;)q=e.appendChild(o);h.insertNode(e);if(q){h=h.cloneRange();h.setStartAfter(q);h.collapse(false);j.removeAllRanges();j.addRange(h)}}}}};else if(Ext.isOpera)return function(d){if(d.getKey()==
 d.TAB){d.stopEvent();this.win.focus();this.execCmd("InsertHTML","&nbsp;&nbsp;&nbsp;&nbsp;");this.deferFocus()}};else if(Ext.isWebKit)return function(d){if(d.getKey()==d.TAB){d.stopEvent();this.execCmd("InsertText","\t");this.deferFocus()}}}(),initEditor:function(){b.apply(this,arguments);this.getWin().addEventListener("dragover",Zarafa.onWindowDragDrop,false);this.getWin().addEventListener("drop",Zarafa.onWindowDragDrop,false)},initFrame:function(){c.apply(this,arguments);if(Ext.isChrome&&window.location.href.search(/#$/)!==
 -1){var d=this.findParentBy(function(j){return j.getEl().isScrollable()});this.getEditorBody().scrollTop=0;d!==null&&d.getEl().scrollTo("top",0)}}})})();(function(){var a=Ext.form.Label.prototype.onRender;Ext.override(Ext.form.Label,{cls:"x-form-item-label",onRender:function(){a.apply(this,arguments);this.positionEl=this.el.wrap({cls:"x-form-item"});this.el.unselectable()}})})();
-(function(){var a=/^(100?|\d?\d)?%?$/,b=/^[1-9]\d*$/i;Ext.apply(Ext.form.VTypes,{percentage:function(c){return a.test(c)},percentageText:_("Value must be between 0% to 100%"),naturalInteger:function(c){return b.test(c)},naturalIntegerText:_("Number must be higher than zero")})})();(function(){var a=Ext.grid.ColumnModel.prototype.setColumnWidth;Ext.override(Ext.grid.ColumnModel,{setColumnWidth:function(b,c){isFinite(c)&&a.apply(this,arguments)}})})();
+(function(){var a=/^(100?|\d?\d)?%?$/,b=/^[1-9]\d*$/i,c=/^(\w+)([\-+.\'][\w]+)*@(\w[\-\w]*\.){1,5}([A-Za-z]){2,10}$/;Ext.apply(Ext.form.VTypes,{percentage:function(d){return a.test(d)},percentageText:_("Value must be between 0% to 100%"),naturalInteger:function(d){return b.test(d)},naturalIntegerText:_("Number must be higher than zero"),email:function(d){return c.test(d)}})})();
+(function(){var a=Ext.grid.ColumnModel.prototype.setColumnWidth;Ext.override(Ext.grid.ColumnModel,{setColumnWidth:function(b,c){isFinite(c)&&a.apply(this,arguments)}})})();
 (function(){var a=Ext.grid.GridPanel.prototype.onClick;Ext.override(Ext.grid.GridPanel,{onClick:function(){a.apply(this,arguments);this.view.focusEl.focus()},reconfigure:function(b,c){this.stateful!==false&&c!==this.colModel&&this.mun(this.colModel,"hiddenchange",this.saveState,this);var d=this.rendered;if(d)if(this.loadMask){this.loadMask.destroy();this.loadMask=new Ext.LoadMask(this.bwrap,Ext.apply({},{store:b},this.initialConfig.loadMask))}this.view&&this.view.initData(b,c);this.store=b;this.colModel=
 c;if(this.stateful!==false){this.initStateEvents();this.initState()}d&&this.view.refresh(true);this.fireEvent("reconfigure",this,b,c)}})})();(function(){var a=Ext.grid.GridView.prototype.onColConfigChange;Ext.override(Ext.grid.GridView,{getColumnWidth:function(b){b=this.cm.getColumnWidth(b);var c=this.borderWidth;return Ext.isNumber(b)?Ext.isBorderBox?b+"px":Math.max(b-c,0)+"px":b},onColConfigChange:function(){var b=this.grid;b.stateful!==false&&b.initState();a.apply(this,arguments)}})})();
 (function(){var a=navigator.userAgent.toLowerCase(),b=!Ext.isOpera&&(/msie/.test(a)||/trident/.test(a)),c=true,d={toString:1};for(var j in d)c=null;if(c)c=["hasOwnProperty","valueOf","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","constructor"];Ext.apply(Ext,{isIE:b,isIE10:b&&/msie 10/.test(a),isIE11:b&&/rv:11/.test(a),clone:function(e){if(e===null||e===undefined)return e;if(e.nodeType&&e.cloneNode)return e.cloneNode(true);var h=Object.prototype.toString.call(e);if(h==="[object Date]")return new Date(e.getTime());
