@@ -773,17 +773,18 @@
 		 */
 		function getExceptionAttachment($base_date)
 		{
-			// Retrieve only embedded messages
+			// Retrieve only exceptions which are stored as embedded messages
 			$attach_res = Array(RES_AND,
 							Array(
 								Array(RES_PROPERTY,
-									Array(RELOP => RELOP_EQ,
+									Array(
+										RELOP => RELOP_EQ,
 										ULPROPTAG => PR_ATTACH_METHOD,
 										VALUE => array(PR_ATTACH_METHOD => ATTACH_EMBEDDED_MSG)
 									)
 								)
 							)
-			);
+						);
 			$attachments = mapi_message_getattachmenttable($this->message);
 			$attachRows = mapi_table_queryallrows($attachments, Array(PR_ATTACH_NUM), $attach_res);
 
@@ -792,10 +793,16 @@
 				{
 					$tempattach = mapi_message_openattach($this->message, $attachRow[PR_ATTACH_NUM]);
 					$exception = mapi_attach_openobj($tempattach);
-			
+
 					$data = mapi_message_getprops($exception, array($this->proptags["basedate"]));
-					
-					if($this->isSameDay($this->fromGMT($this->tz,$data[$this->proptags["basedate"]]), $base_date)) {
+
+					if(!isset($data[$this->proptags["basedate"]])) {
+						// if no basedate found then it could be embedded message so ignore it
+						// we need proper restriction to exclude embedded messages aswell
+						continue;
+					}
+
+					if($this->isSameDay($this->fromGMT($this->tz, $data[$this->proptags["basedate"]]), $base_date)) {
 						return $tempattach;
 					}
 				}
