@@ -134,8 +134,8 @@ class Services_JSON
     *                                   bubble up with an error, so all return values
     *                                   from encode() should be checked with isError()
     *                           - SERVICES_JSON_USE_TO_JSON:  call toJSON when serializing objects
-    *                                   It serializes the return value from the toJSON call rather 
-    *                                   than the object it'self,  toJSON can return associative arrays, 
+    *                                   It serializes the return value from the toJSON call rather
+    *                                   than the object it'self,  toJSON can return associative arrays,
     *                                   strings or numbers, if you return an object, make sure it does
     *                                   not have a toJSON method, otherwise an error will occur.
     */
@@ -150,7 +150,7 @@ class Services_JSON
     var $_mb_strlen = false;
     var $_mb_substr = false;
     var $_mb_convert_encoding = false;
-    
+
    /**
     * convert a string from one UTF-16 char to one UTF-8 char
     *
@@ -252,7 +252,11 @@ class Services_JSON
     */
     function encode($var)
     {
-        header('Content-type: application/json');
+        /*
+         * We want to use this function just for encoding json data, so we should not set header for content type
+         * because it will change content type of index.php and will load index.php as json data instead of html data
+         */
+        //header('Content-type: application/json');
         return $this->encodeUnsafe($var);
     }
     /**
@@ -274,10 +278,10 @@ class Services_JSON
         $ret = $this->_encode($var);
         setlocale(LC_NUMERIC, $lc);
         return $ret;
-        
+
     }
     /**
-    * PRIVATE CODE that does the work of encodes an arbitrary variable into JSON format 
+    * PRIVATE CODE that does the work of encodes an arbitrary variable into JSON format
     *
     * @param    mixed   $var    any number, boolean, string, array, or object to be encoded.
     *                           see argument 1 to Services_JSON() above for array-parsing behavior.
@@ -287,9 +291,9 @@ class Services_JSON
     * @return   mixed   JSON string representation of input var or an error if a problem occurs
     * @access   public
     */
-    function _encode($var) 
+    function _encode($var)
     {
-         
+
         switch (gettype($var)) {
             case 'boolean':
                 return $var ? 'true' : 'false';
@@ -354,7 +358,7 @@ class Services_JSON
                                 $ascii .= '?';
                                 break;
                             }
-                            
+
                             $char = pack('C*', $ord_var_c, ord($var{$c + 1}));
                             $c += 1;
                             $utf16 = $this->utf82utf16($char);
@@ -480,27 +484,27 @@ class Services_JSON
                 return '[' . join(',', $elements) . ']';
 
             case 'object':
-            
+
                 // support toJSON methods.
                 if (($this->use & SERVICES_JSON_USE_TO_JSON) && method_exists($var, 'toJSON')) {
                     // this may end up allowing unlimited recursion
                     // so we check the return value to make sure it's not got the same method.
                     $recode = $var->toJSON();
-                    
+
                     if (method_exists($recode, 'toJSON')) {
-                        
+
                         return ($this->use & SERVICES_JSON_SUPPRESS_ERRORS)
                         ? 'null'
                         : new Services_JSON_Error(class_name($var).
                             " toJSON returned an object with a toJSON method.");
-                            
+
                     }
-                    
+
                     return $this->_encode( $recode );
-                } 
-                
+                }
+
                 $vars = get_object_vars($var);
-                
+
                 $properties = array_map(array($this, 'name_value'),
                                         array_keys($vars),
                                         array_values($vars));
@@ -764,7 +768,7 @@ class Services_JSON
                                 // element in an associative array,
                                 // for now
                                 $parts = array();
-                                
+
                                if (preg_match('/^\s*(["\'].*[^\\\]["\'])\s*:/Uis', $slice, $parts)) {
  	                              // "name":value pair
                                     $key = $this->decode($parts[1]);
@@ -871,28 +875,28 @@ class Services_JSON
 
         return false;
     }
-    
+
     /**
     * Calculates length of string in bytes
-    * @param string 
+    * @param string
     * @return integer length
     */
-    function strlen8( $str ) 
+    function strlen8( $str )
     {
         if ( $this->_mb_strlen ) {
             return mb_strlen( $str, "8bit" );
         }
         return strlen( $str );
     }
-    
+
     /**
     * Returns part of a string, interpreting $start and $length as number of bytes.
-    * @param string 
-    * @param integer start 
-    * @param integer length 
+    * @param string
+    * @param integer start
+    * @param integer length
     * @return integer length
     */
-    function substr8( $string, $start, $length=false ) 
+    function substr8( $string, $start, $length=false )
     {
         if ( $length === false ) {
             $length = $this->strlen8( $string ) - $start;
@@ -929,7 +933,7 @@ if (class_exists('PEAR_Error')) {
 
         }
     }
-    
+
 }
 
 // Future-friendly json_encode
