@@ -115,12 +115,12 @@ class Conversion {
 						break;
 					case PT_SRESTRICTION:
 						if(!empty($value)) {
-							$properties[$mapi_property] = Conversion::json2restriction($value);
+							$properties[$mapi_property] = Conversion::json2restriction($props, $value);
 						}
 						break;
 					case PT_ACTIONS:
 						if(!empty($value)) {
-							$properties[$mapi_property] = Conversion::json2actions($value);
+							$properties[$mapi_property] = Conversion::json2actions($props, $value);
 						}
 						break;
 					default:
@@ -132,11 +132,11 @@ class Conversion {
 
 		// The body is a bit special, as we have to consider the HTML body and the plain-text body
 		$isHTML = isset($message_properties["isHTML"]) && $message_properties["isHTML"] == true;
-		if (isset($message_properties["html_body"]) && $isHTML && !empty($message_properties["html_body"])) {
+		if (isset($message_properties["html_body"]) && $isHTML) {
 			$properties[PR_INTERNET_CPID] = 65001; // always write UTF-8 codepage
 			$properties[PR_HTML] = $message_properties["html_body"];
 			$properties[PR_BODY] = $message_properties["html_body"];
-		} else if (isset($message_properties["body"]) && !$isHTML && !empty($message_properties["body"])) {
+		} else if (isset($message_properties["body"]) && !$isHTML) {
 			$properties[PR_INTERNET_CPID] = 65001; // always write UTF-8 codepage
 			$properties[PR_BODY] = $message_properties["body"];
 		}
@@ -249,22 +249,37 @@ class Conversion {
 	 *
 	 * Note that this depends on the definition of the property tag constants
 	 * in mapitags.php
+	 * Mappings are defined per module in class.properties.php
 	 *
-	 * @example json2property('PR_SUBJECT') => 0x0037001e
+	 * @example json2property('subject') => 0x0037001e
+	 * @example this also works json2property('PR_SUBJECT') => 0x0037001e
+	 * @param Array props A mapping of property names to their corresponding MAPI property tags
 	 * @param String property name
+	 * @param Boolean $convertToSingleValued wether to convert the multi valued property tag to single valued or not
 	 * @return int The property tag
 	 */
-	public static function json2property($json)
+	public static function json2property($mapping, $prop, $convertToSingleValued = false)
 	{
-		if (is_string($json)) {
-			if (defined($json)) {
-				return constant($json);
-			} else {
-				return hexdec($json);
-			}
+		$propTag = false;
+
+		if (isset($mapping[$prop])) {
+			// Normally we would go for this case, where the property is defined in our mapping
+			$propTag = $mapping[$prop];
+		} else if (defined($prop)) {
+			// This is for cases where the proptag reference is defined as a constant, e.g. PR_BODY
+			$propTag = constant($prop);
+		} else {
+			// In this case we expect the string to be a hex id of the proptag
+			$propTag = hexdec($prop);
 		}
 
-		return $json;
+		// if getting multi valued property then sometimes we need to convert it to
+		// its single valued counterpart to use in VALUES structure of restriction
+		if($convertToSingleValued) {
+			$propTag = Conversion::convertToSingleValuedProperty($propTag);
+		}
+
+		return $propTag;
 	}
 
 	/**
@@ -303,10 +318,11 @@ class Conversion {
 	 * Convert an JSON restriction structure into a MAPI SRestriction array
 	 *
 	 * @access private
+	 * @param {Array} $mapping An associative array mapping propety keys to MAPI proptags
 	 * @param {Array} $json The parsed JSON array data
 	 * @return {Array} MAPI restriction array compatible with MAPI extension restriction format
 	 */
-	public static function json2restriction($json)
+	public static function json2restriction($mapping, $json)
 	{
 		if (!is_array($json)){
 			return $json;
@@ -317,23 +333,23 @@ class Conversion {
 			case RES_OR:
 				if(isset($json[1][0]) && is_array($json[1][0])) {
 					foreach($json[1] as &$res) {
-						$res = Conversion::json2restriction($res);
+						$res = Conversion::json2restriction($mapping, $res);
 					}
 					unset($res);
 				} else if(!empty($json[1])) {
-					$json[1] = Conversion::json2restriction($json[1]);
+					$json[1] = Conversion::json2restriction($mapping, $json[1]);
 				}
 				break;
 			case RES_NOT:
 				// Note that a normal RES_NOT restriction should not be placed
 				// in an array, but the php-ext does expect an array to be
 				// given, so we wrap it here.
-				$json[1] = array( Conversion::json2restriction($json[1]) );
+				$json[1] = array( Conversion::json2restriction($mapping, $json[1]) );
 				break;
 			case RES_COMMENT:
 				$props = array();
 				foreach($json[1][PROPS] as $propTag => $propValue){
-					$propTag = Conversion::json2property($propTag);
+					$propTag = Conversion::json2property($mapping, $propTag);
 					if (mapi_prop_type($propTag) === PT_BINARY) {
 						$propValue = hex2bin($propValue);
 					}
@@ -341,18 +357,34 @@ class Conversion {
 				}
 
 				$json[1][PROPS] = $props;
-				$json[1][RESTRICTION] = Conversion::json2restriction($json[1][RESTRICTION]);
+				$json[1][RESTRICTION] = Conversion::json2restriction($mapping, $json[1][RESTRICTION]);
 				break;
 			case RES_PROPERTY:
 			case RES_CONTENT:
-				$json[1][ULPROPTAG] = Conversion::json2property($json[1][ULPROPTAG]);
+				$json[1][ULPROPTAG] = Conversion::json2property($mapping, $json[1][ULPROPTAG]);
 				$value = array();
 
 				foreach ($json[1][VALUE] as $propTag => $propValue) {
-					$propTag = Conversion::json2property($propTag);
-					if (mapi_prop_type($propTag) === PT_BINARY) {
+					$propTag = Conversion::json2property($mapping, $propTag, true);
+					$type = mapi_prop_type($propTag);
+
+					if ($type === PT_BINARY) {
 						$propValue = hex2bin($propValue);
+					} else if ($type === PT_MV_STRING8) {
+						// Convert multivalued strings to arrays
+						$mv_values = explode(";", $propValue);
+						$values = array();
+
+						foreach($mv_values as $mv_value)
+						{
+							if(!empty($mv_value)) {
+								$values[] = ltrim($mv_value);
+							}
+						}
+
+						$propValue = !empty($values) ? $values : array();
 					}
+
 					$value[$propTag] = $propValue;
 				}
 
@@ -360,17 +392,17 @@ class Conversion {
 				$json[1][VALUE] = $value;
 				break;
 			case RES_COMPAREPROPS:
-				$json[1][ULPROPTAG1] = Conversion::json2property($json[1][ULPROPTAG1]);
-				$json[1][ULPROPTAG2] = Conversion::json2property($json[1][ULPROPTAG2]);
+				$json[1][ULPROPTAG1] = Conversion::json2property($mapping, $json[1][ULPROPTAG1]);
+				$json[1][ULPROPTAG2] = Conversion::json2property($mapping, $json[1][ULPROPTAG2]);
 				break;
 			case RES_BITMASK:
 			case RES_SIZE:
 			case RES_EXIST:
-				$json[1][ULPROPTAG] = Conversion::json2property($json[1][ULPROPTAG]);
+				$json[1][ULPROPTAG] = Conversion::json2property($mapping, $json[1][ULPROPTAG]);
 				break;
 			case RES_SUBRESTRICTION:
-				$json[1][ULPROPTAG] = Conversion::json2property($json[1][ULPROPTAG]);
-				$json[1][RESTRICTION] = Conversion::json2restriction($json[1][RESTRICTION]);
+				$json[1][ULPROPTAG] = Conversion::json2property($mapping, $json[1][ULPROPTAG]);
+				$json[1][RESTRICTION] = Conversion::json2restriction($mapping, $json[1][RESTRICTION]);
 				break;
 		}
 
@@ -488,7 +520,7 @@ class Conversion {
 	 * @param {Array} $actions JSON representation PT_ACTIONS structure
 	 * @return {Array} Converted PT_ACTIONS structure that can be used in MAPI
 	 */
-	public static function json2actions($actions)
+	public static function json2actions($mapping, $actions)
 	{
 		foreach($actions as &$action) {
 			foreach($action as $key => $value) {
@@ -507,7 +539,7 @@ class Conversion {
 							$recipient = Array();
 
 							foreach($addr as $addrkey => $addrval) {
-								$addrkey = Conversion::json2property($addrkey);
+								$addrkey = Conversion::json2property($mapping, $addrkey);
 
 								if (mapi_prop_type($addrkey) === PT_BINARY) {
 									$addrval = hex2bin($addrval);
