@@ -1,5 +1,5 @@
 <?php
-	require('server/exceptions/class.DispatcherException.php');
+	require(__DIR__ . '/../exceptions/class.DispatcherException.php');
 
 	/**
 	* On-demand module loader
