@@ -10,11 +10,20 @@
 		const STATIC_GUID_FAVORITE = '00000000000000000000000000000002';
 		/* GUID of ipm_subtree of public store*/
 		const STATIC_GUID_FAVSUBTREE = '00000000000000000000000000000001';
+		/* GUID of Global Addressbook */
+		const MUIDECSAB = 'AC21A95040D3EE48B319FBA753304425';
 		/* GUID of Contact Provider */
-		const STATIC_GUID_CONTACT_PROVIDER = '727F0430E3924FDAB86AE52A7FE46571';
+		const MUIDZCSAB = '727F0430E3924FDAB86AE52A7FE46571';
 		/* GUID for OneOff entryid */
 		const MAPI_ONE_OFF_UID = '812B1FA4BEA310199D6E00DD010F5402';
 
+		/* Hardcoded ID used for generating entryid of addressbook container */
+		const ZARAFA_UID_ADDRESS_BOOK = '00000000';
+		/* Hardcoded ID used for generating entryid of global addressbook container */
+		const ZARAFA_UID_GLOBAL_ADDRESS_BOOK = '01000000';
+		/* Hardcoded ID used for generating entryid of global addresslists container */
+		const ZARAFA_UID_GLOBAL_ADDRESS_LISTS = '02000000';
+
 		/**
 		 * Default constructor
 		 */
@@ -103,7 +112,7 @@
 				'server'	=> '',		// CHAR,     variable length
 				'padding'	=> '',		// TCHAR[3],  4 bytes,  8 hex characters (upto 4 bytes)
 			);
-	
+
 			$res['length'] = strlen($entryId);
 			$offset = 0;
 
@@ -232,7 +241,7 @@
 				'muid'			=> '',	// MAPIUID,  16 bytes, 32 hex characters
 				'ulObjType'		=> '',	// ULONG,     4 bytes,  8 hex characters
 				'ulOffset'		=> '',	// ULONG,     4 bytes,  8 hex characters
-				'unWrappedEntryId'	=> '',	// EID/EID_V0,  variable length because it contains server name	
+				'unWrappedEntryId'	=> '',	// EID/EID_V0,  variable length because it contains server name
 			);
 
 			$res['length'] = strlen($entryId);
@@ -282,11 +291,11 @@
 		}
 
 		/**
-		 * Compares two entryIds. It is possible to have two different entryIds that should match as they 
+		 * Compares two entryIds. It is possible to have two different entryIds that should match as they
 		 * represent the same object (in multiserver environments).
 		 * @param {String} entryId1 EntryID
 		 * @param {String} entryId2 EntryID
-		 * @return {Boolean} Result of the comparison 
+		 * @return {Boolean} Result of the comparison
 		 */
 		public function compareEntryIds($entryId1, $entryId2)
 		{
@@ -342,11 +351,11 @@
 		}
 
 		/**
-		 * Compares two entryIds. It is possible to have two different entryIds that should match as they 
+		 * Compares two entryIds. It is possible to have two different entryIds that should match as they
 		 * represent the same object (in multiserver environments).
 		 * @param {String} storeEntryId1 store entryid
 		 * @param {String} storeEntryId2 store entryid
-		 * @return {Boolean} Result of the comparison 
+		 * @return {Boolean} Result of the comparison
 		 */
 		public function compareStoreEntryIds($storeEntryId1, $storeEntryId2)
 		{
@@ -414,14 +423,12 @@
 		public function wrapABEntryIdObj($entryId, $objType)
 		{
 			$objType = dechex($objType);
-			if (strlen($objType) === 1) {
-				$objType = '0' . $objType;
-			}
-			while (strlen($objType) < 8) {
-				$objType .= '0';
-			}
 
-			return '00000000' + self::STATIC_GUID_CONTACT_PROVIDER + $objType + '00000000' + $entryId;
+			// add padding for the type, which is of 4 bytes (8 characters)
+			$objType = str_pad($objType, 2, '0', STR_PAD_LEFT);
+			$objType = str_pad($objType, 8, '0', STR_PAD_RIGHT);
+
+			return '00000000' + self::MUIDZCSAB + $objType + '00000000' + $entryId;
 		}
 
 		/**
@@ -436,11 +443,11 @@
 		}
 
 		/**
-		 * Compares two entryIds. It is possible to have two different entryIds that should match as they 
+		 * Compares two entryIds. It is possible to have two different entryIds that should match as they
 		 * represent the same object (in multiserver environments).
 		 * @param {String} entryId1 EntryID
 		 * @param {String} entryId2 EntryID
-		 * @return {Boolean} Result of the comparison 
+		 * @return {Boolean} Result of the comparison
 		 */
 		public function compareABEntryIds($entryId1, $entryId2)
 		{
@@ -499,7 +506,7 @@
 		{
 			$entryIdObj = $this->createEntryIdObj($entryId);
 
-			return ($entryIdObj['guid'] == self::MAPI_ONE_OFF_UID); 
+			return $entryIdObj['guid'] == self::MAPI_ONE_OFF_UID;
 		}
 
 		/**
@@ -511,7 +518,7 @@
 		{
 			$entryIdObj = $this->createEntryIdObj($entryId);
 
-			return ($entryIdObj['uniqueId'] == self::STATIC_GUID_FAVORITE);
+			return $entryIdObj['uniqueId'] == self::STATIC_GUID_FAVORITE;
 		}
 
 		/**
@@ -523,7 +530,7 @@
 		{
 			$entryIdObj = $this->createEntryIdObj($entryId);
 
-			return ($entryIdObj['uniqueId'] == self::STATIC_GUID_PUBLICFOLDER);
+			return $entryIdObj['uniqueId'] == self::STATIC_GUID_PUBLICFOLDER;
 		}
 
 		/**
@@ -535,17 +542,49 @@
 		{
 			$entryIdObj = $this->createEntryIdObj($entryId);
 
-			return ($entryIdObj['uniqueId'] == self::STATIC_GUID_FAVSUBTREE);
+			return $entryIdObj['uniqueId'] == self::STATIC_GUID_FAVSUBTREE;
 		}
 
 		/**
 		 * Checks if the given entryid
 		 * @param {String} entryId Addressbook entryid
-		 * 
+		 *
 		 */
-		public function hasContactProviderGUID($entryId){
+		public function hasContactProviderGUID($entryId)
+		{
 			$entryIdObj = $this->createABEntryIdObj($entryId);
-			return ($entryIdObj && $entryIdObj['guid'] == self::STATIC_GUID_CONTACT_PROVIDER);
+
+			return $entryIdObj['guid'] == self::MUIDZCSAB;
+		}
+
+		/**
+		 * Checks if the GUID part of the entryid is of the Global Addressbook.
+		 * @param {String} $entryId Address Book entryid
+		 * @return {Boolean} true if guid matches the Global Addressbook else false
+		 */
+		public function hasAddressBookGUID($entryId)
+		{
+			$entryIdObj = $this->createABEntryIdObj($entryId);
+
+			return $entryIdObj['guid'] == self::MUIDECSAB;
+		}
+
+		/**
+		 * Checks if the GUID part of the entryid is of the Global Addressbook Container.
+		 * @param {String} $entryId Address Book entryid
+		 * @return {Boolean} true if guid matches the Global Addressbook Container else false
+		 */
+		public function isGlobalAddressbookContainer($entryId)
+		{
+			// check for global addressbook entryid
+			if($this->hasAddressBookGUID($entryId) === false) {
+				return false;
+			}
+
+			$entryIdObj = $this->createABEntryIdObj($entryId);
+
+			// check for object_type == MAPI_ABCONT and id == 1
+			return ($entryIdObj['type'] == '04000000' && $entryIdObj['id'] == self::ZARAFA_UID_GLOBAL_ADDRESS_BOOK);
 		}
 	}
 
