@@ -10,6 +10,9 @@
  * the output from magicHTML is therefore only an XSS-safe version of the same input.
  *
  * Fixed bug in sq_fixstyle to not remove styles from html comments as they are useful
+ *
+ * Fixed bug in sq_sanitize to not add extra \n at start and end of the body as they are treated as
+ * new line by tinymce editor
  */
 
 /**
@@ -958,7 +961,7 @@ function sq_sanitize($body,
      */
     $curpos = 0;
     $open_tags = Array();
-    $trusted = "\n<!-- begin sanitized html -->\n";
+    $trusted = "<!-- begin sanitized html -->";
     $skip_content = false;
     /**
      * Take care of netscape's stupid javascript entities like
@@ -1093,7 +1096,7 @@ function sq_sanitize($body,
         }
         $trusted .= "\n";
     }
-    $trusted .= "<!-- end sanitized html -->\n";
+    $trusted .= "<!-- end sanitized html -->";
     return $trusted;
 }
 
