@@ -14,7 +14,7 @@
 		function ContactItemModule($id, $data)
 		{
 			$this->properties = $GLOBALS['properties']->getContactProperties();
-			
+
 			parent::ItemModule($id, $data);
 
 			$this->plaintext = true;
@@ -158,7 +158,10 @@
 					}
 
 					if (!empty($members) && !empty($oneoff_members)) {
-						$props[$this->properties['members']] = $members;
+						// At the moment server is expecting oneoff entryids in members property
+						// @TODO: Re-enable this when ZCP-12047 is fixed
+						//$props[$this->properties['members']] = $members;
+						$props[$this->properties['members']] = $oneoff_members;
 						$props[$this->properties['oneoff_members']] = $oneoff_members;
 					} else {
 						$properiesToDelete[] = $this->properties['members'];
