@@ -1,5 +1,5 @@
 <?php
-	require('server/exceptions/class.SearchException.php');
+	require(__DIR__ . '/../exceptions/class.SearchException.php');
 
 	/**
 	 * Module
@@ -160,6 +160,10 @@
 						else
 							$e->setDisplayMessage(_("Error in search, please try again."));
 						break;
+
+					case "expand":
+						$e->setDisplayMessage(_("Error in distribution list expansion."));
+						break;
 				}
 			}
 		}
