@@ -1,6 +1,6 @@
 <?php
-	include_once('mapi/class.taskrecurrence.php');
-	include_once("mapi/class.taskrequest.php");
+	include_once(__DIR__ . '/../../mapi/class.taskrecurrence.php');
+	include_once(__DIR__ . '/../../mapi/class.taskrequest.php');
 
 	/**
 	 * Task ItemModule
